"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var currencies_1 = require("./currencies/currencies");
var CurrencyConverter = /** @class */ (function () {
    function CurrencyConverter(rates, base) {
        this.rates = rates;
        this.base = base || currencies_1.Currencies.EUR;
    }
    /**
     * Convert a price from one currency to another.
     *
     * @param {IConvertObject} convertObject The conversion object that specifies amount and which currencies the
     * conversion involves.
     * @returns {number | null} The amount in the new currency.
     */
    CurrencyConverter.prototype.convert = function (convertObject) {
        // No conversion needed
        if (convertObject.from.getCode() === convertObject.to.getCode()) {
            return convertObject.amount;
        }
        // Check that both currencies are given in the rates dict
        if ((!this.rates.hasOwnProperty(convertObject.from.getCode())
            && this.base.getCode() !== convertObject.from.getCode())
            || (!this.rates.hasOwnProperty(convertObject.to.getCode()))
                && this.base.getCode() !== convertObject.to.getCode()) {
            // If one is missing return null
            return null;
        }
        // Convert to the base currency
        var convertTo = convertObject.to.getCode() !== this.base.getCode() ?
            this.rates[convertObject.to.getCode()] : 1;
        // Convert from the base currency
        var convertFrom = convertObject.from.getCode() !== this.base.getCode() ?
            1 / this.rates[convertObject.from.getCode()] : 1;
        return convertTo * convertFrom * convertObject.amount;
    };
    return CurrencyConverter;
}());
exports.CurrencyConverter = CurrencyConverter;
//# sourceMappingURL=currency-converter.js.map