import { IProduct } from "./interfaces/product";
import { IAddProduct, IProductData } from "./interfaces/product-data";
import { IWeightUnit } from "./interfaces/weight-unit";
import { ICurrency } from "./interfaces/currency";
import { Observable } from "typescript-observable";
import { ICartConfig } from "./interfaces/cart-config";
export declare class Product extends Observable implements IProduct {
    private id;
    private productData;
    constructor(id: number, data: IAddProduct, cartConfig: ICartConfig);
    /**
     * Get the id of the product. This id is specific for the cart of the products.
     * @returns {number} The id
     */
    getId(): number;
    /**
     * Get the name of the product
     * @returns {string} The product name
     */
    getName(): string;
    /**
     * Get the product data. This object contains all data about the object. Use functions in this class if possible to
     * change the object rather than changing it directly.
     * @returns {IProductData}
     */
    getData(): IProductData;
    /**
     * Get the quantity of the product.
     * @returns {number} The quantity
     */
    getQuantity(): number;
    /**
     * Set the quantity.
     * @param {number} quantity The new quantity.
     * @param {boolean} add If true the quantity is added, if false the new quantity will overwrite the old.
     * @returns {IProduct} Chaining this
     */
    setQuantity(quantity: number, add?: boolean): IProduct;
    /**
     * Remove the product from cart
     * @return {Promise<void>} A promise when the product is removed
     */
    remove(): Promise<void>;
    /**
     * Get the weight of the product
     * @param {IWeightUnit} weightUnit the weight units to use
     * @returns {number} The weight of the cart
     */
    getWeight(weightUnit: IWeightUnit): number;
    /**
     * Get the total price of this product
     * @param {boolean} vat
     * @returns {number}
     */
    getTotalPrice(vat: boolean): number;
    /**
     * Get the currency of this product.
     * @returns {ICurrency} The currency
     */
    getCurrency(): ICurrency;
    /**
     * Get the vat of this product
     * @returns {number} The vat
     */
    getVat(): number;
    /**
     * Get the extra data of this product
     * @returns {any}
     */
    getExtra(): any;
}
